"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var EnvErrorType;
(function (EnvErrorType) {
    EnvErrorType["MISSING"] = "MISSING";
    EnvErrorType["WRONG_TYPE"] = "WRONG_TYPE";
})(EnvErrorType = exports.EnvErrorType || (exports.EnvErrorType = {}));
class EnvError extends Error {
    constructor(report) {
        super(formatReport(report));
        this.name = 'EnvError';
        this.report = report;
    }
}
exports.EnvError = EnvError;
function formatReport(report) {
    const errors = Object.entries(report).map(entry => {
        const [key, { type, schemaValue, receivedValue }] = entry;
        return formatError(key, type, schemaValue, receivedValue);
    });
    return `Invalid or missing environment variables\n    - ${errors.join('\n    - ')}\n`;
}
function formatError(key, type, schemaValue, value) {
    switch (type) {
        case EnvErrorType.MISSING:
            return `Expected value for key '${key}'; none found`;
        case EnvErrorType.WRONG_TYPE:
            if (schemaValue instanceof RegExp) {
                return `Expected value for key '${key}' to match ${schemaValue}; got '${value}'`;
            }
            if (schemaValue instanceof Array) {
                const expectedValues = schemaValue.map(value => `'${value}'`).join(', ');
                return `Expected value for key '${key}' to be one of ${expectedValues}; got ${value}`;
            }
            return `Expected value for key '${key}' of type ${schemaValue.name}; got '${value}'`;
    }
}
//# sourceMappingURL=EnvError.js.map